@@ -48,8 +48,10 @@ def flush_ip_cache_file():
 # HELPERS
 
 def get_yaml_setting(setting="urls"):
+    log.debug("reading file: {}".format(yaml_file))
     f = open(yaml_file)
     url_updater_hash = yaml.load(f)
+    log.debug("yaml hash: {}".format(url_updater_hash))
     return url_updater_hash[setting]
 
 def ip_addy_changed(external_ip, prev_ext_ip):
@@ -114,7 +116,7 @@ def read_yaml_update_urls(yaml_conf="/etc/external_ip_updater/urls.yaml"):
 
 def get_ip_from_router():
     s = requests.Session()
-    set_trace()
+    # set_trace()
     credentials = get_yaml_setting("router_credentials")
     s.auth = (credentials["username"], credentials["password"])
     resp = s.get('http://192.168.1.1/cgi-bin/status_deviceinfo.asp', auth=HTTPBasicAuth('isnoatNictav', 'RokzucNeofhu'))
